/*
 * Copyright (C) 2016-2022 Jolla Ltd.
 * Copyright (C) 2016-2022 Slava Monich <slava.monich@jolla.com>
 *
 * You may use this file under the terms of BSD license as follows:
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 *   1. Redistributions of source code must retain the above copyright
 *      notice, this list of conditions and the following disclaimer.
 *   2. Redistributions in binary form must reproduce the above copyright
 *      notice, this list of conditions and the following disclaimer in the
 *      documentation and/or other materials provided with the distribution.
 *   3. Neither the names of the copyright holders nor the names of its
 *      contributors may be used to endorse or promote products derived
 *      from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS"
 * AND ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
 * ARE DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDERS OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS
 * INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN
 * CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE)
 * ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF
 * THE POSSIBILITY OF SUCH DAMAGE.
 *
 * The views and conclusions contained in the software and documentation
 * are those of the authors and should not be interpreted as representing
 * any official policies, either expressed or implied.
 */

#ifndef MCE_PROXY_H
#define MCE_PROXY_H

#include "mce_types_p.h"

#include <glib-object.h>

typedef struct mce_proxy_priv MceProxyPriv;
struct _ComNokiaMceSignal;
struct _ComNokiaMceRequest;

typedef struct mce_proxy {
    GObject object;
    MceProxyPriv* priv;
    gboolean valid;
    struct _ComNokiaMceSignal* signal;
    struct _ComNokiaMceRequest* request;
} MceProxy;

typedef void
(*MceProxyFunc)(
    MceProxy* proxy,
    void* arg);

MceProxy*
mce_proxy_new(
    void)
    MCE_INTERNAL;

MceProxy*
mce_proxy_ref(
    MceProxy* proxy)
    MCE_INTERNAL;

void
mce_proxy_unref(
    MceProxy* proxy)
    MCE_INTERNAL;

gulong
mce_proxy_add_valid_changed_handler(
    MceProxy* proxy,
    MceProxyFunc fn,
    void* arg)
    MCE_INTERNAL;

void
mce_proxy_remove_handler(
    MceProxy* proxy,
    gulong id)
    MCE_INTERNAL;

#endif /* MCE_PROXY_H */

/*
 * Local Variables:
 * mode: C
 * c-basic-offset: 4
 * indent-tabs-mode: nil
 * End:
 */
